<?php
/**
 * Singleton klass för att hantera sessioner...
 * self::$var syntax för static $this->var för vanliga variabler
 * Man vill försäkra sig om att det vara skall finnas ett objekt av klassen service_session
 * $_SESSION[$section][$key] om $key anges, annars $_SESSION[$section]
 *
 *
 * @author jf
 */

class service_session {

	private static $instance;

	// Privat för att förhindara att man skapar objekt via new
	final private function __construct() {
		session_name(SESSION_NAME);
		session_start();
	}

	// Privat för att förhindra att man skapar en kopia av ett objekt
	final private function __clone() { }


	// Det är med denna funktion man skapar ett object eller hämtar det skapade objektet
	public static function getInstance()
	{
		if (!isset(self::$instance)) {
			$c = __CLASS__;
			self::$instance = new $c;
		}
		return self::$instance;
	}


	public function Destroy() {
		session_destroy();
	}

	/**
	 * Behöver ett sätt att kommunicera med användarna
	 * @param $message
	 */
	public function AddError($message) {
		$_SESSION['Errors'][] = $message;
	}

	/**
	 * Behöver ett sätt att kommunicera med användarna
	 * @param $message
	 */
	public function AddSuccess($message) {
		$_SESSION['Success'][] = $message;
	}

	/**
	 * Skriver ut alla Errors och alla Success, tömmer sedan dessa variabler
	 */
	public function PrintInfo() {
		// Skriver ut alla errors om det finns några
		if (count($_SESSION['Errors'])) {
			echo '<div class="error">ERROR<br>';
			foreach($_SESSION['Errors'] as $error) {
				echo $error . '<br>';
			}
			echo '</div>';
			unset($_SESSION['Errors']);
		}
		// Skriver ut info om det finns någon
		if (count($_SESSION['Success'])) {
			echo '<div class="success">SUCCESS<br>';
			foreach($_SESSION['Success'] as $success) {
				echo $success . '<br>';
			}
			echo '</div>';
			unset($_SESSION['Success']);
		}
	}

	/**
	 * 
	 * Kolla om man är inloggad, och type skickas med så kan man lägga till fler kollar
	 * $type == Admin - då kollar man om man har adminrättigheter
	 * @param $type
	 */
	public function CheckLogin($type=false) {
		if(!$this->Get('UserID') && !$type) {
			header ('location: '. INDEX .'?c=login&a=login');
			exit();
		}
		if($type == 'Admin' && !$this->Get('Admin')) {
			$this->AddError('You are not Admin');
			header ('location: ' . INDEX);
			exit();
		}
		return true;
	}

	public function Set($value, $section, $key = '') {
		if (empty($key)) {
			$_SESSION[$section] = $value;
		} else {
			if ($key == 'ai') { // ai = auto increament
				$_SESSION[$section][count($_SESSION[$section])] = $value;
			} else {
				$_SESSION[$section][$key] = $value;
			}
		}
	}

	public function Get($section, $key = '') {
		if (empty($key) && isset($_SESSION[$section])) {
			return $_SESSION[$section];
		} elseif (!empty($key) && isset($_SESSION[$section][$key])) {
			return $_SESSION[$section][$key];
		}
		return false;
	}

	public function Delete($section, $key = '') {
		if (empty($key) && isset($_SESSION[$section])) {
			unset($_SESSION[$section]);
			return true;
		} elseif (!empty($key) && isset($_SESSION[$section][$key])) {
			unset($_SESSION[$section][$key]);
			return true;
		}
		return false;
	}
}
